
#include <assert.h>
#include <stdio.h>
#include <sys/types.h>

#include "ttterm.h"
#include "ttbuffer.h"
#include "ttutils.h"
#include "ttstrat.h"
#include "ttstratp.h"

#include "c/VSCParse.h"
#include "utils.h"


static TTterm
select_name(TTterm t)
{
	TTterm result;

	if (TTmatchVSC_expr_data_name(t, &result)) {
		return result;
	}
	return 0;
}

static TTterm
select_string_f(TTterm t)
{
	TTterm u, x;

	if (TTmatch_sandwich(t, &u, &x, &u)) {
		return select_string_f(x);
	} else if (t->fun == TTfun_string) {
		return t;
	}
	return 0;
}

TTterm
select_string(TTterm t)
{
	return TTselect(t, select_string_f);
}

TTterm
get_name(TTterm t)
{
	TTterm result = TTselect(t, select_name);
	if (result) return select_string(result);
	return 0;
}

TTtype_list
fixpoint(TTtype_list known, TTterm t, TTtype_list (*f)(TTtype_list ts, TTterm t))
{
	TTtype_list known2 = TTunion(known, f(known, t));
	while (!TTequal(known2, known)) {
		known = known2;
		known2 = TTunion(known2, f(known, t));
	}
	return known2;
}

TTterm
select_term(TTterm t, TTterm (*f)(TTterm))
{
	TTterm result;
	struct TTstrat_env_struct env;
	TTterm s;
	s = TTbuild_oncetd(TTbuild_adhoc(f));
	env.comb = TTconcat;
	env.empty = TTbuild_nil();
	result = TTstrat_apply(s, t, &env);
	return result;
}

TTterm
transform(TTterm t, TTterm (*f)(TTterm))
{
	TTterm result;
	TTterm s = TTbuild_totaltd(TTbuild_try(TTbuild_adhoc(f)));
	result = TTstrat_apply_tp(s, t);
	assert(result != 0);
	return result;
}

TTterm
analyze(TTterm t,
        TTterm (*f)(TTterm),
	TTterm(*comb)(TTterm t, TTterm t2),
	TTterm empty)
{
	TTterm result;
	struct TTstrat_env_struct env;
	TTterm s = TTbuild_totaltd(TTbuild_try(TTbuild_adhoc(f)));
	env.comb = comb;
	env.empty = empty;
	result = TTstrat_apply(s, t, &env);
	assert(result != 0);
	return result;
}

