%{
#include "ttterm.h"
#include "ttbuffer.h"
#include "ttutils.h"
#include "ttparse.h"
#include "tterror.h"
#include "VSCFuns.h"
#include "VSCScan.h"

#define BUFSZ 1024
static char st_buf[BUFSZ];

static void build_token(void)
{
	yylval = TTparse_word((size_t)yyleng);
}

%}
%x PIC
%option noyywrap
WS [ \t\n]
COM (\*>.*\n)
%%

({WS}|{COM}|(","{WS}))+ { build_token(); return FLEX_LAYOUT; }

"SPACE" { build_token(); return FLEX_T_SPACE; }
"SPACES" { build_token(); return FLEX_T_SPACES; }
"HIGH-VALUE" { build_token(); return FLEX_T_HIGH_VALUE; }
"HIGH-VALUES" { build_token(); return FLEX_T_HIGH_VALUES; }
"LOW-VALUE" { build_token(); return FLEX_T_LOW_VALUE; }
"LOW-VALUES" { build_token(); return FLEX_T_LOW_VALUES; }
"QUOTE" { build_token(); return FLEX_T_QUOTE; }
"QUOTES" { build_token(); return FLEX_T_QUOTES; }
"NULL" { build_token(); return FLEX_T_NULL; }
"NULLS" { build_token(); return FLEX_T_NULLS; }
"ACCESS" { build_token(); return FLEX_T_ACCESS; }
"PROCEDURES" { build_token(); return FLEX_T_PROCEDURES; }
"UP" { build_token(); return FLEX_T_UP; }
"DOWN" { build_token(); return FLEX_T_DOWN; }
"SENTENCE" { build_token(); return FLEX_T_SENTENCE; }
"MORE-LABELS" { build_token(); return FLEX_T_MORE_LABELS; }
"REMOVAL" { build_token(); return FLEX_T_REMOVAL; }
"VALUES" { build_token(); return FLEX_T_VALUES; }
"ENVIRONMENT" { build_token(); return FLEX_T_ENVIRONMENT; }
"IDENTIFICATION" { build_token(); return FLEX_T_IDENTIFICATION; }
"ID" { build_token(); return FLEX_T_ID; }
"AUTHOR" { build_token(); return FLEX_T_AUTHOR; }
"INSTALLATION" { build_token(); return FLEX_T_INSTALLATION; }
"DATE-WRITTEN" { build_token(); return FLEX_T_DATE_WRITTEN; }
"DATE-COMPILED" { build_token(); return FLEX_T_DATE_COMPILED; }
"SECURITY" { build_token(); return FLEX_T_SECURITY; }
"REMARKS" { build_token(); return FLEX_T_REMARKS; }
"PROGRAM-ID" { build_token(); return FLEX_T_PROGRAM_ID; }
"INPUT-OUTPUT" { build_token(); return FLEX_T_INPUT_OUTPUT; }
"FILE-CONTROL" { build_token(); return FLEX_T_FILE_CONTROL; }
"ORGANIZATION" { build_token(); return FLEX_T_ORGANIZATION; }
"SEQUENTIAL" { build_token(); return FLEX_T_SEQUENTIAL; }
"RANDOM" { build_token(); return FLEX_T_RANDOM; }
"DYNAMIC" { build_token(); return FLEX_T_DYNAMIC; }
"SELECT" { build_token(); return FLEX_T_SELECT; }
"OPTIONAL" { build_token(); return FLEX_T_OPTIONAL; }
"ASSIGN" { build_token(); return FLEX_T_ASSIGN; }
"RESERVE" { build_token(); return FLEX_T_RESERVE; }
"AREAS" { build_token(); return FLEX_T_AREAS; }
"PADDING" { build_token(); return FLEX_T_PADDING; }
"PASSWORD" { build_token(); return FLEX_T_PASSWORD; }
"RELATIVE" { build_token(); return FLEX_T_RELATIVE; }
"ALTERNATE" { build_token(); return FLEX_T_ALTERNATE; }
"I-O-CONTROL" { build_token(); return FLEX_T_I_O_CONTROL; }
"EVERY" { build_token(); return FLEX_T_EVERY; }
"MULTIPLE" { build_token(); return FLEX_T_MULTIPLE; }
"TAPE" { build_token(); return FLEX_T_TAPE; }
"POSITION" { build_token(); return FLEX_T_POSITION; }
"APPLY" { build_token(); return FLEX_T_APPLY; }
"WRITE-ONLY" { build_token(); return FLEX_T_WRITE_ONLY; }
"RERUN" { build_token(); return FLEX_T_RERUN; }
"SORT-MERGE" { build_token(); return FLEX_T_SORT_MERGE; }
"SAME" { build_token(); return FLEX_T_SAME; }
"AREA" { build_token(); return FLEX_T_AREA; }
"CONFIGURATION" { build_token(); return FLEX_T_CONFIGURATION; }
"SOURCE-COMPUTER" { build_token(); return FLEX_T_SOURCE_COMPUTER; }
"DEBUGGING" { build_token(); return FLEX_T_DEBUGGING; }
"OBJECT-COMPUTER" { build_token(); return FLEX_T_OBJECT_COMPUTER; }
"WORDS" { build_token(); return FLEX_T_WORDS; }
"MODULES" { build_token(); return FLEX_T_MODULES; }
"MEMORY" { build_token(); return FLEX_T_MEMORY; }
"SEGMENT-LIMIT" { build_token(); return FLEX_T_SEGMENT_LIMIT; }
"SPECIAL-NAMES" { build_token(); return FLEX_T_SPECIAL_NAMES; }
"OFF" { build_token(); return FLEX_T_OFF; }
"STATUS" { build_token(); return FLEX_T_STATUS; }
"ALPHABET" { build_token(); return FLEX_T_ALPHABET; }
"STANDARD-1" { build_token(); return FLEX_T_STANDARD_1; }
"STANDARD-2" { build_token(); return FLEX_T_STANDARD_2; }
"NATIVE" { build_token(); return FLEX_T_NATIVE; }
"EBCDIC" { build_token(); return FLEX_T_EBCDIC; }
"SYMBOLIC" { build_token(); return FLEX_T_SYMBOLIC; }
"ARE" { build_token(); return FLEX_T_ARE; }
"CLASS" { build_token(); return FLEX_T_CLASS; }
"CURRENCY" { build_token(); return FLEX_T_CURRENCY; }
"DECIMAL-POINT" { build_token(); return FLEX_T_DECIMAL_POINT; }
"COMMA" { build_token(); return FLEX_T_COMMA; }
"WORKING-STORAGE" { build_token(); return FLEX_T_WORKING_STORAGE; }
"LINKAGE" { build_token(); return FLEX_T_LINKAGE; }
"FD" { build_token(); return FLEX_T_FD; }
"SD" { build_token(); return FLEX_T_SD; }
"BLOCK" { build_token(); return FLEX_T_BLOCK; }
"RECORDS" { build_token(); return FLEX_T_RECORDS; }
"CONTAINS" { build_token(); return FLEX_T_CONTAINS; }
"OMITTED" { build_token(); return FLEX_T_OMITTED; }
"VALUE" { build_token(); return FLEX_T_VALUE; }
"LINAGE" { build_token(); return FLEX_T_LINAGE; }
"FOOTING" { build_token(); return FLEX_T_FOOTING; }
"TOP" { build_token(); return FLEX_T_TOP; }
"BOTTOM" { build_token(); return FLEX_T_BOTTOM; }
"RECORDING" { build_token(); return FLEX_T_RECORDING; }
"MODE" { build_token(); return FLEX_T_MODE; }
"CODE-SET" { build_token(); return FLEX_T_CODE_SET; }
"FILLER" { build_token(); return FLEX_T_FILLER; }
"REDEFINES" { build_token(); return FLEX_T_REDEFINES; }
"BLANK" { build_token(); return FLEX_T_BLANK; }
"EXTERNAL" { build_token(); return FLEX_T_EXTERNAL; }
"JUSTIFIED" { build_token(); return FLEX_T_JUSTIFIED; }
"JUST" { build_token(); return FLEX_T_JUST; }
"OCCURS" { build_token(); return FLEX_T_OCCURS; }
"INDEXED" { build_token(); return FLEX_T_INDEXED; }
"SIGN" { build_token(); return FLEX_T_SIGN; }
"SEPARATE" { build_token(); return FLEX_T_SEPARATE; }
"CHARACTER" { build_token(); return FLEX_T_CHARACTER; }
"TRAILING" { build_token(); return FLEX_T_TRAILING; }
"LEFT" { build_token(); return FLEX_T_LEFT; }
"RIGHT" { build_token(); return FLEX_T_RIGHT; }
"SYNCHRONIZED" { build_token(); return FLEX_T_SYNCHRONIZED; }
"SYNC" { build_token(); return FLEX_T_SYNC; }
"USAGE" { build_token(); return FLEX_T_USAGE; }
"BINARY" { build_token(); return FLEX_T_BINARY; }
"COMP" { build_token(); return FLEX_T_COMP; }
"COMP-1" { build_token(); return FLEX_T_COMP_1; }
"COMP-2" { build_token(); return FLEX_T_COMP_2; }
"COMP-3" { build_token(); return FLEX_T_COMP_3; }
"COMP-4" { build_token(); return FLEX_T_COMP_4; }
"COMPUTATIONAL" { build_token(); return FLEX_T_COMPUTATIONAL; }
"COMPUTATIONAL-1" { build_token(); return FLEX_T_COMPUTATIONAL_1; }
"COMPUTATIONAL-2" { build_token(); return FLEX_T_COMPUTATIONAL_2; }
"COMPUTATIONAL-3" { build_token(); return FLEX_T_COMPUTATIONAL_3; }
"COMPUTATIONAL-4" { build_token(); return FLEX_T_COMPUTATIONAL_4; }
"DISPLAY-1" { build_token(); return FLEX_T_DISPLAY_1; }
"INDEX" { build_token(); return FLEX_T_INDEX; }
"PACKED-DECIMAL" { build_token(); return FLEX_T_PACKED_DECIMAL; }
"RENAMES" { build_token(); return FLEX_T_RENAMES; }
"DIVISION" { build_token(); return FLEX_T_DIVISION; }
"DECLARATIVES" { build_token(); return FLEX_T_DECLARATIVES; }
"SECTION" { build_token(); return FLEX_T_SECTION; }
"ACCEPT" { build_token(); return FLEX_T_ACCEPT; }
"DATE" { build_token(); return FLEX_T_DATE; }
"DAY" { build_token(); return FLEX_T_DAY; }
"DAY-OF-WEEK" { build_token(); return FLEX_T_DAY_OF_WEEK; }
"TIME" { build_token(); return FLEX_T_TIME; }
"ADD" { build_token(); return FLEX_T_ADD; }
"END-ADD" { build_token(); return FLEX_T_END_ADD; }
"ALTER" { build_token(); return FLEX_T_ALTER; }
"PROCEED" { build_token(); return FLEX_T_PROCEED; }
"CALL" { build_token(); return FLEX_T_CALL; }
"END-CALL" { build_token(); return FLEX_T_END_CALL; }
"REFERENCE" { build_token(); return FLEX_T_REFERENCE; }
"CONTENT" { build_token(); return FLEX_T_CONTENT; }
"CANCEL" { build_token(); return FLEX_T_CANCEL; }
"CLOSE" { build_token(); return FLEX_T_CLOSE; }
"LOCK" { build_token(); return FLEX_T_LOCK; }
"COMPUTE" { build_token(); return FLEX_T_COMPUTE; }
"END-COMPUTE" { build_token(); return FLEX_T_END_COMPUTE; }
"CONTINUE" { build_token(); return FLEX_T_CONTINUE; }
"DELETE" { build_token(); return FLEX_T_DELETE; }
"END-DELETE" { build_token(); return FLEX_T_END_DELETE; }
"DISPLAY" { build_token(); return FLEX_T_DISPLAY; }
"UPON" { build_token(); return FLEX_T_UPON; }
"DIVIDE" { build_token(); return FLEX_T_DIVIDE; }
"REMAINDER" { build_token(); return FLEX_T_REMAINDER; }
"END-DIVIDE" { build_token(); return FLEX_T_END_DIVIDE; }
"ENTRY" { build_token(); return FLEX_T_ENTRY; }
"EVALUATE" { build_token(); return FLEX_T_EVALUATE; }
"END-EVALUATE" { build_token(); return FLEX_T_END_EVALUATE; }
"ALSO" { build_token(); return FLEX_T_ALSO; }
"OTHER" { build_token(); return FLEX_T_OTHER; }
"ANY" { build_token(); return FLEX_T_ANY; }
"TRUE" { build_token(); return FLEX_T_TRUE; }
"FALSE" { build_token(); return FLEX_T_FALSE; }
"EXIT" { build_token(); return FLEX_T_EXIT; }
"PROGRAM" { build_token(); return FLEX_T_PROGRAM; }
"GOBACK" { build_token(); return FLEX_T_GOBACK; }
"GO" { build_token(); return FLEX_T_GO; }
"DEPENDING" { build_token(); return FLEX_T_DEPENDING; }
"IF" { build_token(); return FLEX_T_IF; }
"END-IF" { build_token(); return FLEX_T_END_IF; }
"ELSE" { build_token(); return FLEX_T_ELSE; }
"INITIALIZE" { build_token(); return FLEX_T_INITIALIZE; }
"ALPHANUMERIC" { build_token(); return FLEX_T_ALPHANUMERIC; }
"ALPHANUMERIC-EDITED" { build_token(); return FLEX_T_ALPHANUMERIC_EDITED; }
"NUMERIC-EDITED" { build_token(); return FLEX_T_NUMERIC_EDITED; }
"EGCS" { build_token(); return FLEX_T_EGCS; }
"DATA" { build_token(); return FLEX_T_DATA; }
"CONVERTING" { build_token(); return FLEX_T_CONVERTING; }
"INSPECT" { build_token(); return FLEX_T_INSPECT; }
"LEADING" { build_token(); return FLEX_T_LEADING; }
"FIRST" { build_token(); return FLEX_T_FIRST; }
"CHARACTERS" { build_token(); return FLEX_T_CHARACTERS; }
"INITIAL" { build_token(); return FLEX_T_INITIAL; }
"MERGE" { build_token(); return FLEX_T_MERGE; }
"MOVE" { build_token(); return FLEX_T_MOVE; }
"MULTIPLY" { build_token(); return FLEX_T_MULTIPLY; }
"END-MULTIPLY" { build_token(); return FLEX_T_END_MULTIPLY; }
"OPEN" { build_token(); return FLEX_T_OPEN; }
"REVERSED" { build_token(); return FLEX_T_REVERSED; }
"NO" { build_token(); return FLEX_T_NO; }
"REWIND" { build_token(); return FLEX_T_REWIND; }
"TIMES" { build_token(); return FLEX_T_TIMES; }
"PERFORM" { build_token(); return FLEX_T_PERFORM; }
"END-PERFORM" { build_token(); return FLEX_T_END_PERFORM; }
"UNTIL" { build_token(); return FLEX_T_UNTIL; }
"TEST" { build_token(); return FLEX_T_TEST; }
"READ" { build_token(); return FLEX_T_READ; }
"NEXT" { build_token(); return FLEX_T_NEXT; }
"END-READ" { build_token(); return FLEX_T_END_READ; }
"RELEASE" { build_token(); return FLEX_T_RELEASE; }
"RETURN" { build_token(); return FLEX_T_RETURN; }
"RECORD" { build_token(); return FLEX_T_RECORD; }
"END-RETURN" { build_token(); return FLEX_T_END_RETURN; }
"REWRITE" { build_token(); return FLEX_T_REWRITE; }
"END-REWRITE" { build_token(); return FLEX_T_END_REWRITE; }
"VARYING" { build_token(); return FLEX_T_VARYING; }
"SEARCH" { build_token(); return FLEX_T_SEARCH; }
"WHEN" { build_token(); return FLEX_T_WHEN; }
"END-SEARCH" { build_token(); return FLEX_T_END_SEARCH; }
"END" { build_token(); return FLEX_T_END; }
"=" { build_token(); return '='; }
"SET" { build_token(); return FLEX_T_SET; }
"SORT" { build_token(); return FLEX_T_SORT; }
"ASCENDING" { build_token(); return FLEX_T_ASCENDING; }
"DESCENDING" { build_token(); return FLEX_T_DESCENDING; }
"DUPLICATES" { build_token(); return FLEX_T_DUPLICATES; }
"ORDER" { build_token(); return FLEX_T_ORDER; }
"COLLATING" { build_token(); return FLEX_T_COLLATING; }
"SEQUENCE" { build_token(); return FLEX_T_SEQUENCE; }
"THROUGH" { build_token(); return FLEX_T_THROUGH; }
"THRU" { build_token(); return FLEX_T_THRU; }
"USING" { build_token(); return FLEX_T_USING; }
"START" { build_token(); return FLEX_T_START; }
"END-START" { build_token(); return FLEX_T_END_START; }
"STOP" { build_token(); return FLEX_T_STOP; }
"RUN" { build_token(); return FLEX_T_RUN; }
"STRING" { build_token(); return FLEX_T_STRING; }
"END-STRING" { build_token(); return FLEX_T_END_STRING; }
"GIVING" { build_token(); return FLEX_T_GIVING; }
"SUBTRACT" { build_token(); return FLEX_T_SUBTRACT; }
"ROUNDED" { build_token(); return FLEX_T_ROUNDED; }
"END-SUBTRACT" { build_token(); return FLEX_T_END_SUBTRACT; }
"SIZE" { build_token(); return FLEX_T_SIZE; }
"CORRESPONDING" { build_token(); return FLEX_T_CORRESPONDING; }
"CORR" { build_token(); return FLEX_T_CORR; }
"UNSTRING" { build_token(); return FLEX_T_UNSTRING; }
"INTO" { build_token(); return FLEX_T_INTO; }
"END-UNSTRING" { build_token(); return FLEX_T_END_UNSTRING; }
"DELIMITED" { build_token(); return FLEX_T_DELIMITED; }
"DELIMITER" { build_token(); return FLEX_T_DELIMITER; }
"COUNT" { build_token(); return FLEX_T_COUNT; }
"WITH" { build_token(); return FLEX_T_WITH; }
"POINTER" { build_token(); return FLEX_T_POINTER; }
"TALLYING" { build_token(); return FLEX_T_TALLYING; }
"OVERFLOW" { build_token(); return FLEX_T_OVERFLOW; }
"WRITE" { build_token(); return FLEX_T_WRITE; }
"END-WRITE" { build_token(); return FLEX_T_END_WRITE; }
"LINE" { build_token(); return FLEX_T_LINE; }
"LINES" { build_token(); return FLEX_T_LINES; }
"PAGE" { build_token(); return FLEX_T_PAGE; }
"BEFORE" { build_token(); return FLEX_T_BEFORE; }
"ADVANCING" { build_token(); return FLEX_T_ADVANCING; }
"FROM" { build_token(); return FLEX_T_FROM; }
"INVALID" { build_token(); return FLEX_T_INVALID; }
"KEY" { build_token(); return FLEX_T_KEY; }
"END-OF-PAGE" { build_token(); return FLEX_T_END_OF_PAGE; }
"EOP" { build_token(); return FLEX_T_EOP; }
"AT" { build_token(); return FLEX_T_AT; }
"COPY" { build_token(); return FLEX_T_COPY; }
"SUPPRESS" { build_token(); return FLEX_T_SUPPRESS; }
"." { build_token(); return '.'; }
"IN" { build_token(); return FLEX_T_IN; }
"BY" { build_token(); return FLEX_T_BY; }
"REPLACING" { build_token(); return FLEX_T_REPLACING; }
"EXCEPTION" { build_token(); return FLEX_T_EXCEPTION; }
"ERROR" { build_token(); return FLEX_T_ERROR; }
"GLOBAL" { build_token(); return FLEX_T_GLOBAL; }
"AFTER" { build_token(); return FLEX_T_AFTER; }
"STANDARD" { build_token(); return FLEX_T_STANDARD; }
"LABEL" { build_token(); return FLEX_T_LABEL; }
"PROCEDURE" { build_token(); return FLEX_T_PROCEDURE; }
"BEGINNING" { build_token(); return FLEX_T_BEGINNING; }
"ENDING" { build_token(); return FLEX_T_ENDING; }
"FILE" { build_token(); return FLEX_T_FILE; }
"REEL" { build_token(); return FLEX_T_REEL; }
"UNIT" { build_token(); return FLEX_T_UNIT; }
"INPUT" { build_token(); return FLEX_T_INPUT; }
"OUTPUT" { build_token(); return FLEX_T_OUTPUT; }
"I-O" { build_token(); return FLEX_T_I_O; }
"EXTEND" { build_token(); return FLEX_T_EXTEND; }
"USE" { build_token(); return FLEX_T_USE; }
"FOR" { build_token(); return FLEX_T_FOR; }
"DEBUGGING" { build_token(); return FLEX_T_DEBUGGING; }
"ON" { build_token(); return FLEX_T_ON; }
"NUMERIC" { build_token(); return FLEX_T_NUMERIC; }
"ALPHABETIC" { build_token(); return FLEX_T_ALPHABETIC; }
"ALPHABETIC-LOWER" { build_token(); return FLEX_T_ALPHABETIC_LOWER; }
"ALPHABETIC-UPPER" { build_token(); return FLEX_T_ALPHABETIC_UPPER; }
"DBCS" { build_token(); return FLEX_T_DBCS; }
"KANJI" { build_token(); return FLEX_T_KANJI; }
"IS" { build_token(); return FLEX_T_IS; }
"THAN" { build_token(); return FLEX_T_THAN; }
"THEN" { build_token(); return FLEX_T_THEN; }
">" { build_token(); return '>'; }
"<" { build_token(); return '<'; }
"GREATER" { build_token(); return FLEX_T_GREATER; }
"LESS" { build_token(); return FLEX_T_LESS; }
"EQUAL" { build_token(); return FLEX_T_EQUAL; }
"TO" { build_token(); return FLEX_T_TO; }
">=" { build_token(); return FLEX_T_QGT_QEQUAL; }
"POSITIVE" { build_token(); return FLEX_T_POSITIVE; }
"NEGATIVE" { build_token(); return FLEX_T_NEGATIVE; }
"ZERO" { build_token(); return FLEX_T_ZERO; }
"ZEROES" { build_token(); return FLEX_T_ZEROES; }
"ZEROS" { build_token(); return FLEX_T_ZEROS; }
"NOT" { build_token(); return FLEX_T_NOT; }
"AND" { build_token(); return FLEX_T_AND; }
"OR" { build_token(); return FLEX_T_OR; }
":" { build_token(); return ':'; }
"LINAGE-COUNTER" { build_token(); return FLEX_T_LINAGE_COUNTER; }
"*" { build_token(); return '*'; }
"/" { build_token(); return '/'; }
"+" { build_token(); return '+'; }
"-" { build_token(); return '-'; }
"**" { build_token(); return FLEX_T_QMULTIPLY_QMULTIPLY; }
"(" { build_token(); return '('; }
")" { build_token(); return ')'; }
"ALL" { build_token(); return FLEX_T_ALL; }
"ADDRESS" { build_token(); return FLEX_T_ADDRESS; }
"LENGTH" { build_token(); return FLEX_T_LENGTH; }
"OF" { build_token(); return FLEX_T_OF; }



"PICTURE" {
	BEGIN(PIC);
	build_token();
	return FLEX_T_PICTURE;
}

"PIC" {
	BEGIN(PIC);
	build_token();
	return FLEX_T_PIC;
}

[\+\-]?(([0-9]*[\.\,][0-9]+)|[0-9]+) {
	build_token();
	yylval = TTbuildVSC_lex_num(yylval);
	return FLEX_VSC_LEX_NUM;
}

<PIC>([^ \t\n,;.]|([,;.][^ \t\n]))+ {
	BEGIN(INITIAL);
	build_token();
	yylval = TTbuildVSC_lex_picture_string(yylval);
	return FLEX_VSC_LEX_PICTURE_STRING;
}

<PIC>({WS}|{COM})+ {
	build_token();
	return FLEX_LAYOUT;
}

[A-Za-z0-9\-]+ {
	build_token();
	yylval = TTbuildVSC_lex_cobword(yylval);
	return FLEX_VSC_LEX_COBWORD;
}

"=="[^=]*"==" {
	build_token();
	yylval = TTbuildVSC_lex_quoted_pseudo_text(yylval);
	return FLEX_VSC_LEX_QUOTED_PSEUDO_TEXT;
}

["][^"\n]*["] {
	build_token();
	yylval = TTbuildVSC_lex_nonnumeric(yylval);
	return FLEX_VSC_LEX_NONNUMERIC;
}

['][^'\n]*['] {
	build_token();
	yylval = TTbuildVSC_lex_nonnumeric(yylval);
	return FLEX_VSC_LEX_NONNUMERIC;
}

. {
	snprintf(st_buf, BUFSZ, "Illegal character in input: `%c'\n", yytext[0]);
	TTerror(st_buf);
}

%%
