
#include <stdio.h>
#include <stdlib.h>
#include <sys/times.h>
#include <time.h>
#include <unistd.h>

#define MAX_SIZE 1000
#define LOC_MIN 100
#define LOC_MAX 100000

extern int snprintf(char *s,  size_t  n,  const  char  *format, ...);

static void
generate_cobol(int n)
{
	int i;
	FILE * f;

	f = fopen("tmp.cob", "w");

	fprintf(f, "       IDENTIFICATION DIVISION.\n");
	fprintf(f, "        PROGRAM-ID. FOO.\n");
	fprintf(f, "\n");
	fprintf(f, "       DATA DIVISION.\n");
	fprintf(f, "        WORKING-STORAGE SECTION.\n");
	fprintf(f, "         01  FIELD-A PIC 99.\n");
	fprintf(f, "         01  FIELD-B PIC 99.\n");
	fprintf(f, "\n");
	fprintf(f, "       PROCEDURE DIVISION.\n");
	for (i = 9; i < n; i++) {
		fprintf(f, "           MOVE FIELD-A TO FIELD-B.\n");
	}
	fclose(f);
}

static void
time_cmd(const char * parser, const char * cmd)
{
	int i;
	int return_code;
	clock_t before, after, foo;
	struct tms tms_before, tms_after;

	printf("%8s", parser);

	for (i = LOC_MIN; i <= LOC_MAX; i *= 10) {
		foo = times(&tms_before);
		generate_cobol(i);
		return_code = system(cmd);
		foo = times(&tms_after);

		if (return_code == 0) {
			after = tms_after.tms_cutime + tms_after.tms_cstime;
			before = tms_before.tms_cutime + tms_before.tms_cstime;
			printf("%8.2f", (double)(after - before)/sysconf(_SC_CLK_TCK));
		} else {
			printf("%8s", "-");
		}
		fflush(stdout);
	}
	printf("\n");
}

int
main(int argc, char **argv)
{
	int i;

	printf("%8s", "");
	for (i = LOC_MIN; i <= LOC_MAX; i *= 10) {
		printf("%8d", i);
	}
	printf("\n");
	time_cmd("c", "demos/c/vsc-accept < tmp.cob > /dev/null 2> /dev/null");
	time_cmd("btyacc", "demos/btyacc/accept < tmp.cob > /dev/null 2> /dev/null");
	time_cmd("bison", "demos/bison/accept < tmp.cob > /dev/null 2> /dev/null");
	time_cmd("sglr", "sglr -p parsers/sdf/VSCParse.tbl -i tmp.cob > /dev/null 2> /dev/null");
	unlink("tmp.cob");
	return 0;
}

