
#include <stdio.h>
#include <stdlib.h>
#include <sys/times.h>
#include <time.h>
#include <unistd.h>

#define MAX_SIZE 1000
#define LOC_MIN 100
#define LOC_MAX 500

extern int snprintf(char *s,  size_t  n,  const  char  *format, ...);

static void
gencobol(int n)
{
	int i, yys;
	FILE * f;

	f = fopen("tmp.cob", "w");

	fprintf(f, "       IDENTIFICATION DIVISION.\n");
	fprintf(f, "        PROGRAM-ID. LITTLE-Y2K.\n");
	fprintf(f, "\n");
	fprintf(f, "       DATA DIVISION.\n");
	fprintf(f, "        WORKING-STORAGE SECTION.\n");
	fprintf(f, "         01  SEEK-NAME     PIC 99.\n");
	fprintf(f, "         01  BUFFER        PIC 999999.\n");
	fprintf(f, "         01  NON-YY        PIC 99.\n");
	fprintf(f, "         01  OTHER-FIELD-1 PIC 99.\n");
	fprintf(f, "         01  OTHER-FIELD-2 PIC 999.\n");
	fprintf(f, "         01  YYYY          PIC 9999.\n");
	yys = n/2 - 9;
	for (i = 0; i < yys; i++) {
	fprintf(f, "         01  YY-%d PIC 99.\n", i);
	}
	fprintf(f, "\n");
	fprintf(f, "       PROCEDURE DIVISION.\n");
	fprintf(f, "           MOVE SEEK-NAME TO BUFFER.\n");
	fprintf(f, "           MOVE NON-YY TO BUFFER.\n");
	fprintf(f, "           MOVE 42 TO OTHER-FIELD-1.\n");
	fprintf(f, "           MOVE OTHER-FIELD-1 TO OTHER-FIELD-2.\n");
	fprintf(f, "           MOVE SEEK-NAME TO YYYY.\n");
	fprintf(f, "           MOVE SEEK-NAME TO YY-0.\n");
	for (i = 0; i < yys - 1; i++) {
	fprintf(f, "           MOVE YY-%d TO YY-%d.\n", i, i+1);
	}
	fclose(f);
}

static void
time_cmd(const char * cmd)
{
	int return_code;
	clock_t before, after, foo;
	struct tms tms_before, tms_after;

	foo = times(&tms_before);
	return_code = system(cmd);
	foo = times(&tms_after);

	if (return_code == 0) {
		after = tms_after.tms_cutime + tms_after.tms_cstime;
		before = tms_before.tms_cutime + tms_before.tms_cstime;
		printf("%8.2f", (double)(after - before)/sysconf(_SC_CLK_TCK));
	} else {
		printf("%8s", "-");
	}
	fflush(stdout);
}

int
main(int argc, char **argv)
{
	int i;
	FILE * f;

	f = fopen("foo.p", "w");
	fprintf(f, "plot \"foo.dat\" using 1:2 title 'hsexpand' with linespoints, \\\n");
	fprintf(f, "     \"foo.dat\" using 1:3 title 'C strategies' with linespoints, \\\n");
	fprintf(f, "     \"foo.dat\" using 1:4 title 'C traversals' with linespoints\n");
	fclose(f);
	for (i = LOC_MIN; i <= LOC_MAX; i += 50) {
		gencobol(i);
		printf("%8d", i);
		time_cmd("../demos/hsexpand/hsexpand < tmp.cob > /dev/null 2> /dev/null");
		time_cmd("../demos/stratexpand/stratexpand < tmp.cob > /dev/null 2> /dev/null");
		time_cmd("../demos/expand/expand < tmp.cob > /dev/null 2> /dev/null");
		printf("\n");
	}
	printf("\n");
	unlink("tmp.cob");
	return 0;
}

